Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(75)

Unified Diff: chrome/browser/cocoa/bookmark_bar_controller.mm

Issue 171016: Bookmark STAR bubble (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/app/nibs/BookmarkBubble.xib ('k') | chrome/browser/cocoa/bookmark_bubble_controller.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/cocoa/bookmark_bar_controller.mm
===================================================================
--- chrome/browser/cocoa/bookmark_bar_controller.mm (revision 23676)
+++ chrome/browser/cocoa/bookmark_bar_controller.mm (working copy)
@@ -399,9 +399,9 @@
initWithParentWindow:[[self view] window]
profile:profile_
node:node];
- [controller runModal];
+ [controller runAsModalSheet];
- // runModal will run the window as a sheet. The
+ // runAsModalSheet will run the window as a sheet. The
// BookmarkNameFolderController will release itself when the sheet
// ends.
}
« no previous file with comments | « chrome/app/nibs/BookmarkBubble.xib ('k') | chrome/browser/cocoa/bookmark_bubble_controller.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698